@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_tree.py 11449 2019-04-13 12:42:08Z Lavender $
+# $Id: build_tree.py 11721 2019-09-23 06:30:12Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-13 21:42:08 +0900 (週六, 13 四月 2019) $
-# $Revision: 11449 $
+# $Date: 2019-09-23 15:30:12 +0900 (週一, 23 九月 2019) $
+# $Revision: 11721 $
 
 import os
 
@@ -38,7 +38,13 @@ class Command(BaseCommand):
         self.staticDirs = None
         if hasattr(settings, 'TEMPLATE_EDITOR_PUBLIC_STATIC'):
             self.staticDirs = settings.TEMPLATE_EDITOR_PUBLIC_STATIC
-
+        else:
+            self.staticDirs = [
+                os.path.join(self.staticPath, 'js'),
+                os.path.join(self.staticPath, 'images'),
+                os.path.join(self.staticPath, 'css'),
+            ]
+        
         self.templateDirs = None
         if hasattr(settings, 'TEMPLATE_EDITOR_PUBLIC_TEMPLATES'):
             self.templateDirs = settings.TEMPLATE_EDITOR_PUBLIC_TEMPLATES
